==> dvdisaster-0.72.2.tar.bz2: dvdisaster-0.72.2/documentation/include/toc.php <==

<?php
# dvdisaster: Online doc table of contents (all languages)
# Copyright (C) 2007-2010 The dvdisaster translation team
#
# UTF-8 trigger: äöüß 

# News

section("news");
  de("Neuigkeiten");
  en("News");
  ru("Новости");

subsection("news2008");
  de("2008");
  en("2008");
  ru("2008");

subsection("news2007");
  de("2007");
  en("2007");
  ru("2007");

# Overview

section("index");
  de("Überblick");
  en("Overview");
  ru("Обзор");

subsection("index10");
  de("Beispiele für die Fehlerkorrektur");   
  en("Examples of the error correction");
  ru("Примеры исправления ошибок");

subsection("index20");
  de("dvdisaster ergänzt Qualitäts-Analysen");
  en("dvdisaster complements quality scans");
  ru("dvdisaster дополняет проверки качества");

subsection("index30");
  de("Vor- und  Nachteile von dvdisaster");
  en("Pro and con of dvdisaster");
  ru("dvdisaster: за и против");

# Howtos

section("howtos");
  de("Typische Anwendungen");
  en("Howtos");
  ru("Howto's");

subsection("howtos60");
  de("Das große Bild");
  en("The big picture");
  ru("Общая картина");

subsubsection("howtos61");
  de("Fehlerkorrektur");
  en("error correction");
  ru("исправление ошибок");

subsubsection("howtos62");
  de("richtige Anwendung");
  en("correct usage");
  ru("правильное использование");

subsubsection("howtos63");
  de("falsche Anwendung");
  en("incorrect usage");
  ru("неправильное использование");

subsection("howtos10");
  de("Datenträger auf Lesefehler prüfen");
  en("Scanning media for errors");
  ru("Поиск ошибок на носителях");

subsubsection("howtos11");
  de("Grundeinstellungen");
  en("Basic settings");
  ru("Основные настройки");

subsubsection("howtos12");
  de("Prüfung durchführen");
  en("Performing the test");
  ru("Выполнение проверки");

subsubsection("howtos13");
  de("Ergebnisse bewerten");
  en("Interpreting the results");
  ru("Объяснение результатов");

subsubsection("howtos14");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Дополнительные настройки");

subsection("howtos20");
  de("Fehlerkorrektur-Daten als Datei erzeugen");
  en("Putting error correction data on a separate file");
  ru("Размещение данных для исправления ошибок в отдельном файле");

subsubsection("howtos21");
  de("Entscheidungshilfe");
  en("Decision help");
  ru("Помощь в принятии решения");

subsubsection("howtos22");
  de("Grundeinstellungen");
  en("Basic settings for reading");
  ru("Основные настройки для чтения");

subsubsection("howtos23");
  de("Fehlerkorrektur-Datei erzeugen");
  en("Creating the error correction file");
  ru("Создание файла для исправления ошибок");

subsubsection("howtos24");
  de("Fehlerkorrektur-Datei archivieren");
  en("Archiving error correction files");
  ru("Архивация файлов для исправления ошибок");

subsubsection("howtos25");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Дополнительные параметры");

subsection("howtos30");
  de("Fehlerkorrektur-Daten auf dem Datenträger ablegen");
  en("Putting error correction data on the medium");
  ru("Размещение данных для исправления ошибок на носителе");

subsubsection("howtos31");
  de("Entscheidungshilfe");
  en("Decision help");
  ru("Помощь в принятии решения");

subsubsection("howtos32");
  de("Grundeinstellungen");
  en("Basic settings");
  ru("Основные параметры");

subsubsection("howtos33");
  de("Datenträger erzeugen");
  en("Creating the medium");
  ru("Создание носителя");

subsubsection("howtos34");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Дополнительные параметры");

subsection("howtos40");
  de("Datenträger-Abbild rekonstruieren");
  en("Recovering media images");
  ru("Восстановление образов носителей");

subsubsection("howtos41");
  de("Grundeinstellungen");
  en("Basic settings");
  ru("Основные параметры");

subsubsection("howtos42");
  de("Abbild rekonstruieren");
  en("Recovering the image");
  ru("Восстановление образа");

subsubsection("howtos43");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Дополнительные параметры");

subsection("howtos50");
  de("Informationen über Abbilder und Fehlerkorrektur-Daten anzeigen");
  en("Getting information about images and error correction data");
  ru("Получение информации об образах и данных для исправления ошибок");

subsubsection("howtos51");
  de("Informationen anzeigen");
  en("Show information");
  ru("Показать информацию");

subsubsection("howtos52");
  de("Ausgaben für Fehlerkorrektur-Dateien");
  en("Results for error correction files");
  ru("Результаты для файлов с данными для исправления ошибок");

subsubsection("howtos53");
  de("Ausgaben für erweiterte Abbilder");
  en("Results für augmented images");
  ru("Результаты для дополненных образов");

subsubsection("howtos59");
  de("Beispiele");
  en("Examples");
  ru("Примеры");

subsection("howtos90");
  de("Abbild-Kompatibilität überprüfen");
  en("Testing image compatibility");
  ru("Проверка совместимости образов");

subsubsection("howtos91");
  de("bei Fehlerkorrektur-Dateien");
  en("with error correction files");
  ru("с файлами для исправления ошибок");

subsubsection("howtos92");
  de("beim Ablegen von Fehlerkorrektur-Daten auf dem Datenträger");
  en("when augmenting images with error correction data");
  ru("при дополнении образов данными для исправления ошибок");

subsection("howtosa0");
  de("Bedienelemente");
  en("Dialogs and buttons");
  ru("Диалоги и кнопки");

subsubsection("howtosa1");
  de("Laufwerk auswählen");
  en("Drive selection");
  ru("Выбор привода");

subsubsection("howtosa2");
  de("Abbild-Datei auswählen");
  en("Image file selection");
  ru("Выбор файла образа");

subsubsection("howtosa3");
  de("Fehlerkorrektur-Datei auswählen");
  en("Error correction file selection");
  ru("Выбор файла для исправления ошибок");

subsubsection("howtosa4");
  de("Aktionen beginnen");
  en("Starting actions");
  ru("Начало действий");
# Download

section("download");
  de("Herunterladen");
  en("Download");
  ru("Скачать");

subsection("download10");
  de("Systemvoraussetzungen");
  en("System requirements");
  ru("Системные требования");

subsection("download20");
  de("Digitale Unterschrift");
  en("Digital signature");
  ru("Цифровая подпись");

subsection("download30");
  de("Installation");
  en("Installation");
  ru("Установка");

#subsection("download40");
#  de("Alpha-/Entwicklerversionen");
#  en("Alpha (unstable) versions");
#  ru("Альфа (нестабильные) версии");

# Questions and Answers

section("qa");
  de("Fragen und Antworten");
  en("Questions and Answers");
  ru("Вопросы и ответы");

subsection("qa10");
  de("Technische Fragen");
  en("Technical Questions");
  ru("Технические вопросы");

subsection("qa20");
  de("Fehlermeldungen");
  en("Error messages");
  ru("Сообщения об ошибках");

# Feedback

section("feedback");
  de("Fehler berichten");
  en("Bug reporting");
  ru("Сообщения об ошибках");

if(strcmp($mode, "local"))
{
  # Imprint

section("imprint");
  de("Impressum");
  en("Imprint");
  ru("Выходные данные");

   # Privacy notice

section("privacy");
  de("Datenschutzhinweis");
  en("Privacy policy");
  ru("Политика конфиденциальности");
}
?>

==> dvdisaster_0.79.3.orig.tar.bz2: dvdisaster-0.79.3/documentation/include/toc.php <==
<?php
# dvdisaster: Online doc table of contents (all languages)
# Copyright (C) 2007-2010 The dvdisaster translation team
#
# UTF-8 trigger: äöüß 

# News

global $have_experimental;

section("news");
  de("Neuigkeiten");
  en("News");
  ru("Новости");

subsection("news2009");
  de("2009");
  en("2009");
  ru("2009");

subsection("news2008");
  de("2008");
  en("2008");
  ru("2008");

subsection("news2007");
  de("2007");
  en("2007");
  ru("2007");

# Overview

section("index");
  de("Überblick");
  en("Overview");
  ru("Обзор");

subsection("index10");
  de("Beispiele für die Fehlerkorrektur");   
  en("Examples of the error correction");
  ru("Примеры исправления ошибок");

subsection("index20");
  de("dvdisaster ergänzt Qualitäts-Analysen");
  en("dvdisaster complements quality scans");
  ru("dvdisaster дополняет проверки качества");

subsection("index30");
  de("Vor- und  Nachteile von dvdisaster");
  en("Pro and con of dvdisaster");
  ru("dvdisaster: за и против");

# Howtos

section("howtos");
  de("Typische Anwendungen");
  en("Howtos");
  ru("Howto's");

subsection("howtos60");
  de("Das große Bild");
  en("The big picture");
  ru("Общая картина");

subsubsection("howtos61");
  de("Fehlerkorrektur");
  en("error correction");
  ru("исправление ошибок");

subsubsection("howtos62");
  de("richtige Anwendung");
  en("correct usage");
  ru("правильное использование");

subsubsection("howtos63");
  de("falsche Anwendung");
  en("incorrect usage");
  ru("неправильное использование");

subsection("howtos10");
  de("Datenträger auf Lesefehler prüfen");
  en("Scanning media for errors");
  ru("Поиск ошибок на носителях");

subsubsection("howtos11");
  de("Grundeinstellungen");
  en("Basic settings");
  ru("Основные настройки");

subsubsection("howtos12");
  de("Prüfung durchführen");
  en("Performing the test");
  ru("Выполнение проверки");

subsubsection("howtos13");
  de("Ergebnisse bewerten");
  en("Interpreting the results");
  ru("Объяснение результатов");

subsubsection("howtos14");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Дополнительные настройки");

subsection("howtos20");
  de("Fehlerkorrektur-Daten als Datei erzeugen");
  en("Putting error correction data on a separate file");
  ru("Размещение данных для исправления ошибок в отдельном файле");

subsubsection("howtos21");
  de("Entscheidungshilfe");
  en("Decision help");
  ru("Помощь в принятии решения");

subsubsection("howtos22");
  de("Grundeinstellungen");
  en("Basic settings for reading");
  ru("Основные настройки для чтения");

subsubsection("howtos23");
  de("Fehlerkorrektur-Datei erzeugen");
  en("Creating the error correction file");
  ru("Создание файла для исправления ошибок");

subsubsection("howtos24");
  de("Fehlerkorrektur-Datei archivieren");
  en("Archiving error correction files");
  ru("Архивация файлов для исправления ошибок");

subsubsection("howtos25");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Дополнительные параметры");

subsection("howtos30");
  de("Fehlerkorrektur-Daten auf dem Datenträger ablegen");
  en("Putting error correction data on the medium");
  ru("Размещение данных для исправления ошибок на носителе");

subsubsection("howtos31");
  de("Entscheidungshilfe");
  en("Decision help");
  ru("Помощь в принятии решения");

subsubsection("howtos32");
  de("Grundeinstellungen");
  en("Basic settings");
  ru("Основные параметры");

subsubsection("howtos33");
  de("Datenträger erzeugen");
  en("Creating the medium");
  ru("Создание носителя");

subsubsection("howtos34");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Дополнительные параметры");

subsection("howtos40");
  de("Datenträger-Abbild rekonstruieren");
  en("Recovering media images");
  ru("Восстановление образов носителей");

subsubsection("howtos41");
  de("Grundeinstellungen");
  en("Basic settings");
  ru("Основные параметры");

subsubsection("howtos42");
  de("Abbild rekonstruieren");
  en("Recovering the image");
  ru("Восстановление образа");

subsubsection("howtos43");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Дополнительные параметры");

subsection("howtos50");
  de("Informationen über Abbilder und Fehlerkorrektur-Daten anzeigen");
  en("Getting information about images and error correction data");
  ru("Получение информации об образах и данных для исправления ошибок");

subsubsection("howtos51");
  de("Informationen anzeigen");
  en("Show information");
  ru("Показать информацию");

subsubsection("howtos52");
  de("Ausgaben für Fehlerkorrektur-Dateien");
  en("Results for error correction files");
  ru("Результаты для файлов с данными для исправления ошибок");

subsubsection("howtos53");
  de("Ausgaben für erweiterte Abbilder");
  en("Results für augmented images");
  ru("Результаты для дополненных образов");

subsubsection("howtos59");
  de("Beispiele");
  en("Examples");
  ru("Примеры");

subsection("howtos90");
  de("Abbild-Kompatibilität überprüfen");
  en("Testing image compatibility");
  ru("Проверка совместимости образов");

subsubsection("howtos91");
  de("bei Fehlerkorrektur-Dateien");
  en("with error correction files");
  ru("с файлами для исправления ошибок");

subsubsection("howtos92");
  de("beim Ablegen von Fehlerkorrektur-Daten auf dem Datenträger");
  en("when augmenting images with error correction data");
  ru("при дополнении образов данными для исправления ошибок");

subsection("howtosa0");
  de("Bedienelemente");
  en("Dialogs and buttons");
  ru("Диалоги и кнопки");

subsubsection("howtosa1");
  de("Laufwerk auswählen");
  en("Drive selection");
  ru("Выбор привода");

subsubsection("howtosa2");
  de("Abbild-Datei auswählen");
  en("Image file selection");
  ru("Выбор файла образа");

subsubsection("howtosa3");
  de("Fehlerkorrektur-Datei auswählen");
  en("Error correction file selection");
  ru("Выбор файла для исправления ошибок");

subsubsection("howtosa4");
  de("Aktionen beginnen");
  en("Starting actions");
  ru("Начало действий");

# Download

section("download");
  de("Herunterladen");
  en("Download");
  ru("Скачать");

subsection("download10");
  de("Systemvoraussetzungen");
  en("System requirements");
  ru("Системные требования");

subsection("download60");
  de("(Keine) Bedingungen zum Herunterladen");
  en("(No) download terms");
  ru("(No) download terms");

subsection("download20");
  de("Digitale Unterschrift");
  en("Digital signature");
  ru("Цифровая подпись");

subsection("download30");
  de("Installation");
  en("Installation");
  ru("Установка");

if(!strcmp($have_experimental, "yes"))
{
subsection("download40");
  de("Alpha-/Entwicklerversionen");
  en("Alpha (unstable) versions");
  ru("Альфа (нестабильные) версии");
}

subsection("download50");
  de("Zusätzliche Papiere");
  en("Additional resources");
  ru("Additional resources");

# Questions and Answers

section("qa");
  de("Fragen und Antworten");
  en("Questions and Answers");
  ru("Вопросы и ответы");

subsection("qa10");
  de("Technische Fragen");
  en("Technical Questions");
  ru("Технические вопросы");

subsection("qa20");
  de("Fehlermeldungen");
  en("Error messages");
  ru("Сообщения об ошибках");

# Feedback

section("feedback");
  de("Fehler berichten");
  en("Bug reporting");
  ru("Сообщения об ошибках");

if(strcmp($mode, "local"))
{
  # Imprint

section("imprint");
  de("Impressum");
  en("Imprint");
  ru("Выходные данные");

   # Privacy notice

section("privacy");
  de("Datenschutzhinweis");
  en("Privacy policy");
  ru("Политика конфиденциальности");
}
?>
